pub struct RustPackages {
pub packages_by_name: BTreeMap<String, RustPackage>,
}Expand description
A RustPackage structure that contains key data from the rust package manifest.
A RustPackage consists of:
- the root of the package source relative to the workspace
- a list of the dependencies used by the package in the workspace
Example
Fields
packages_by_name: BTreeMap<String, RustPackage>BTreeMap of the packages in the workspace by name
Implementations
Sourceimpl RustPackages
impl RustPackages